#####################################################################################
### Please follow below usage example to run mcfs on Artificial and Alizadeh data. 
### Take the tour over various rmcfs functions. 
#####################################################################################

  ### Try to run 'sudo R CMD javareconf' in bash if 'library(rJava)' fails on your system 
  ### If you use Windows you may need to set up Java parameters to run rJava. 
  ### Please check your Java version and path.
  ### These two lines may be needed only for Windows.
  Sys.setenv(JAVA_HOME="C:\\Program Files\\Java\\jre7\\")
  options(java.home="C:\\Program Files\\Java\\jre7\\")
  
  ####################################
  ######### Artificial data ##########
  ####################################

  ### Set up java parameter and load rmcfs package
  options(java.parameters = "-Xmx4g")
  library(rmcfs)

  # create input data and review it
  adata <- artificial.data(rnd_features = 10)
  showme(adata)
  
  # Parametrize and run MCFS-ID procedure
  result <- mcfs(class~., adata, projections = 100, projectionSize = 4,
                 cutoffPermutations = 3, finalCV = TRUE, finalRuleset = TRUE, 
                 threadsNumber = 2)

  # Print basic information about mcfs result
  print(result)

  # Review cutoff values for all methods
  print(result$cutoff)
  
  # Review cutoff value used in plots
  print(result$cutoff_value)
  
  # Plot & print out distances between subsequent projections. 
  # These are convergence MCFS-ID statistics.
  plot(result, type = "distances")
  print(result$distances)
  
  # Plot & print out 50 most important features and show max RI values from 
  # permutation experiment.
  plot(result, type = "ri", size = 50)
  print(head(result$RI, 50))
  
  # Plot & print out 50 strongest feature interdependencies.
  plot.mcfs(result, type = "id", size = 50)
  print(head(result$ID, 50))
  
  # Plot features ordered by RI_norm. Parameter 'size' is the number of 
  # top features in the chart. We set this parameter a bit larger than cutoff_value.
  plot(result, type = "features", size = result$cutoff_value * 1.1, cex = 1)
  # Here we set 'size' at fixed value 10.
  plot(result, type = "features", size = 10)

  # Plot cv classification result obtained on top features.
  # In the middle of x axis red label denotes cutoff_value.
  plot(result, type = "cv", cv_measure = "wacc", cex = 0.8)

  # Plot & print out confusion matrix. This matrix is the result of 
  # all classifications performed by all decision trees on all s*t datasets.
  plot(result, type = "cmatrix")
  
  # Plot heatmap on top features, only numeric features are presented
  plot(result, type = "heatmap", size = 10, heatmap_norm = 'norm', heatmap_fun = 'median')

  # build interdependencies graph (all default parameters).
  gid <- build.idgraph(result)
  plot(gid, label_dist = 1)
  
  # build interdependencies graph for top 6 features 
  # and top 12 interdependencies and plot all nodes
  gid <- build.idgraph(result, size = 6, size_ID = 12, plot_all_nodes = TRUE)
  plot.idgraph(gid, label_dist = 0.5)
  
  # Export graph to graphML (XML structure)
  path <- tempdir()
  igraph::write.graph(gid, file = paste0(path, "/artificial.graphml"), 
              format = "graphml", prefixAttr = FALSE)
  
  # Export and import results to/from csv files
  export.result(result, path = path, label = "artificial")
  result <- import.result(path = path, label = "artificial")
  
  ####################################
  ########## Alizadeh data ###########
  ####################################
  # Load Alizadeh dataset.
  data(alizadeh)
  showme(alizadeh)
  
  # Fix data types and data values - replace characters such as "," " " "/" etc. 
  # from values and column names and fix data types
  # This function may help if mcfs has any problems with input data
  alizadeh <- fix.data(alizadeh)
  
  # Run MCFS-ID procedure on default parameters. 
  # For larger data (thousands of features) default 'auto' settings are the best.
  # This example may take around 10 minutes but this one is a real dataset with 4026 features.
  result <- mcfs(class~., alizadeh, threadsNumber = 4)
  
  # Print basic information about mcfs result.
  print(result)
  
  # Plot & print out distances between subsequent projections. 
  plot(result, type="distances")
  
  # Show RI values for top 500 features and max RI values from permutation experiment.
  plot(result, type = "ri", size = 500)
  
  # build interdependencies graph.
  gid <- build.idgraph(result, size = 20)
  plot.idgraph(gid, label_dist = 0.3)
  
  # Plot cv classification result obtained on top features.
  # In the middle of x axis red label denotes cutoff_value.
  plot(result, type = "cv", measure = "wacc", cex = 0.8)
  
  
  